@@ -28,16 +28,14 @@ Options:
     -s, --api_server=API_SERVER         address of the Rockset API server to connect to
                                         [default: api.rs2.usw2.rockset.com]
 """
-    parsed_args = docopt(
-        usage, argv=args, version=version(), options_first=True
-    )
+    parsed_args = docopt(usage, argv=args, version=version(), options_first=True)
 
     return cli_main(
-        api_server=parsed_args['--api_server'],
-        api_key=parsed_args['API_KEY'],
-        workspace='commons',
+        api_server=parsed_args["--api_server"],
+        api_key=parsed_args["API_KEY"],
+        workspace="commons",
     )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
